import * as prompts from "@clack/prompts";
import chalk from "chalk";
import readline from "readline";
import { logLine, logNewSection, makeLine } from "./lines.js";
import { lowerFirst } from "./lowerFirst.js";
import { startLineWithDots } from "./startLineWithDots.js";
const s = prompts.spinner();
async function withSpinner(label, task) {
  s.start(`${label}...`);
  try {
    const result = await task();
    s.stop(chalk.green(`\u2705 Passed ${lowerFirst(label)}.`));
    return result;
  } catch (error) {
    s.stop(chalk.red(`\u274C Error ${lowerFirst(label)}.`));
    throw new Error(`Failed ${lowerFirst(label)}`, { cause: error });
  }
}
async function withSpinners(label, tasks) {
  logNewSection(`${label}...`);
  let currentLabel;
  let lastLogged;
  try {
    for (const [label2, run] of tasks) {
      currentLabel = label2;
      const line = makeLine(chalk.gray(` - ${label2}`));
      const stopWriting = startLineWithDots(line);
      await run();
      const lineLength = stopWriting();
      lastLogged = chalk.gray(`${line} \u2714\uFE0F
`);
      readline.clearLine(process.stdout, -1);
      readline.moveCursor(process.stdout, -lineLength, 0);
      process.stdout.write(lastLogged);
    }
    readline.moveCursor(process.stdout, -lastLogged.length, -tasks.length - 2);
    readline.clearScreenDown(process.stdout);
    logNewSection(chalk.green(`\u2705 Passed ${lowerFirst(label)}.`));
  } catch (error) {
    const descriptor = `${lowerFirst(label)} > ${lowerFirst(currentLabel)}`;
    logLine(chalk.red(`\u274C Error ${descriptor}.`));
    throw new Error(`Failed ${descriptor}`, { cause: error });
  }
}
export {
  withSpinner,
  withSpinners
};
//# sourceMappingURL=spinners.js.map