import { z } from 'zod';
import { StatusCode } from './codes.js';

interface AllContributorContributor {
    contributions: string[];
    login: string;
}
interface AllContributorsData {
    contributors: AllContributorContributor[];
}
interface PartialPackageData {
    author?: {
        email: string;
        name: string;
    } | string;
    dependencies?: Record<string, string>;
    description?: string;
    devDependencies?: Record<string, string>;
    email?: string;
    name?: string;
    repository?: {
        type: string;
        url: string;
    } | string;
}
type OptionsAccess = "public" | "restricted";
type OptionsBase = "common" | "everything" | "minimum" | "prompt";
interface OptionsEmail {
    github: string;
    npm: string;
}
interface OptionsLogo {
    alt: string;
    src: string;
}
/**
 * All runtime options that may (or must) be specified for setup.
 */
interface Options {
    access: OptionsAccess;
    author?: string;
    base?: OptionsBase;
    description: string;
    directory: string;
    email: OptionsEmail;
    excludeAllContributors?: boolean;
    excludeCompliance?: boolean;
    excludeLintDeprecation?: boolean;
    excludeLintESLint?: boolean;
    excludeLintJSDoc?: boolean;
    excludeLintJson?: boolean;
    excludeLintKnip?: boolean;
    excludeLintMd?: boolean;
    excludeLintPackageJson?: boolean;
    excludeLintPackages?: boolean;
    excludeLintPerfectionist?: boolean;
    excludeLintRegex?: boolean;
    excludeLintSpelling?: boolean;
    excludeLintStrict?: boolean;
    excludeLintStylistic?: boolean;
    excludeLintYml?: boolean;
    excludeReleases?: boolean;
    excludeRenovate?: boolean;
    excludeTests?: boolean;
    funding?: string;
    keywords?: string[];
    logo: OptionsLogo | undefined;
    mode: Mode;
    offline?: boolean;
    owner: string;
    preserveGeneratedFrom?: boolean;
    repository: string;
    skipAllContributorsApi?: boolean;
    skipGitHubApi?: boolean;
    skipInstall?: boolean;
    skipRemoval?: boolean;
    skipRestore?: boolean;
    skipUninstall?: boolean;
    title: string;
}
/**
 * Options that might be suggested by how the user is running setup.
 */
interface PromptedOptions {
    /**
     * Directory for the repository, if it may differ from the repository name.
     */
    directory?: string;
    /**
     * Repository name, if it may differ from the current directory.
     */
    repository?: string;
}
interface ModeResult {
    code: StatusCode;
    error?: string | z.ZodError<object>;
    options: Partial<Options>;
}
type ModeRunner = (args: string[], promptedOptions?: PromptedOptions) => Promise<ModeResult>;
type Mode = "create" | "initialize" | "migrate";

export { AllContributorContributor, AllContributorsData, Mode, ModeResult, ModeRunner, Options, OptionsAccess, OptionsBase, OptionsEmail, OptionsLogo, PartialPackageData, PromptedOptions };
